@@ -37,6 +37,20 @@ For more information, please refer to <https://unlicense.org>
 """
 
 _scheduled_reports_endpoints = [
+  [
+    "scheduled-reports.launch",
+    "POST",
+    "/reports/entities/scheduled-reports/execution/v1",
+    "Launch scheduled reports executions for the provided report IDs.",
+    "scheduled_reports",
+    [
+      {
+        "name": "body",
+        "in": "body",
+        "required": True
+      }
+    ]
+  ],
   [
     "scheduled-reports.get",
     "GET",
