@@ -56,8 +56,8 @@ class Recon(ServiceClass):
     - a valid token provided by the authentication service class (OAuth2.token())
     """
 
-    @force_default(defaults=["body"], default_types=["dict"])
-    def aggregate_notifications(self: object, body: dict = None, **kwargs) -> dict:
+    @force_default(defaults=["body"], default_types=["list"])
+    def aggregate_notifications(self: object, body: list = None, **kwargs) -> dict:
         """Get notification aggregates as specified via JSON in request body.
 
         Keyword arguments:
@@ -117,7 +117,8 @@ class Recon(ServiceClass):
         https://assets.falcon.crowdstrike.com/support/api/swagger.html#/recon/AggregateNotificationsV1
         """
         if not body:
-            body = aggregate_payload(submitted_keywords=kwargs)
+            # Issue 664: Recon aggregate requires a list.
+            body = [aggregate_payload(submitted_keywords=kwargs)]
 
         return process_service_request(
             calling_object=self,
